Statistics (`scipy.stats`)
==========================

.. sectionauthor:: Travis E. Oliphant
.. sectionauthor:: Josef Perktold
.. sectionauthor:: Nicky van Foreest
.. sectionauthor:: Sambit Panda
.. sectionauthor:: Pamphile T. Roy (@tupui)

.. currentmodule:: scipy

In this tutorial, we discuss many, but certainly not all, features of
``scipy.stats``. The intention here is to provide a user with a
working knowledge of this package. We refer to the
:ref:`reference manual <statsrefmanual>` for further details.

Note: This documentation is work in progress.

.. toctree::
   :caption: Contents
   :maxdepth: 2

   stats/probability_distributions
   stats/rv_infrastructure
   stats/sampling
   stats/kernel_density_estimation
   stats/multiscale_graphcorr
   stats/quasi_monte_carlo

.. toctree::
    :caption: Sample statistics and hypothesis tests
    :maxdepth: 2

    stats/analysing_one_sample
    stats/comparing_two_samples
    stats/resampling
    stats/hypothesis_tests